@@ -12,10 +12,15 @@ should.py:
 '''
 
 from functools import partial
-from contextlib import contextmanager
 import re
 import sys
 
+PY3 = sys.version_info[0] == 3
+
+if not PY3:
+    reload(sys)
+    sys.setdefaultencoding('utf8')
+
 
 _just_chains = {
     'should': None, 'have': 'have', 'an': None, 'of': None,
@@ -50,8 +55,6 @@ _assertions = {
     'endswith': lambda exp, actual: actual.endswith(exp),
         # it('abc').should.be.length(3)
     'length': lambda exp, actual: len(actual) == exp,
-        # it({'a': 1}).should.have.key('a')
-    'key': lambda exp, actual: exp in actual.keys(),
         # it('a').should.be.instanceof(basestring)
     'instanceof': lambda exp, actual: isinstance(actual, exp),
         # it('string').should.match(r'tr.')
@@ -112,21 +115,7 @@ class _Should(object):
         self._assert(res, msg(self._flag))
         return self
 
-    @staticmethod
-    @contextmanager
-    def raises(exception):
-        '''
-        异常的断言, 会在 0.5 废弃
-        @param {Exception} exception 需要抛出的异常
-        '''
-        try:
-            yield
-            sys.stderr.write(
-                'raises will be deprecated in 0.5, use throw please.\n')
-        except exception:
-            pass
-        else:
-            assert False, 'should raise ' + exception.__name__
+    raises = throw
 
     @classmethod
     def _set_property(cls, dct, fget, fset=None):
@@ -210,22 +199,19 @@ class _Should(object):
         self.length(0)
         return self
 
-    def proper(self, name):
-        self.__property(name, False)
-        # 修改链式调用中需要断言的值
-        self._val = getattr(self._val, name)
+
+    def key(self, name):
+        '''
+        键值断言. 针对字典的键. 会改变链式调用的断言值.
+        不存在的 key 会将链式调用值变为 None
+        Sample:
+            >>> it({'a':1, 'b':2}).should.have.key('a').which.should.be.equal(1)
+            >>> it({'a':1, 'b':2}).should.have.key('c').which.should.be.none
+        '''
+        self.__key(name)
+        self._val = self._val.get(name, None)
         return self
 
-    property = proper
-
-    def own_proper(self, name):
-        self.__property(name, True)
-        # 修改链式调用中需要断言的值
-        self._val = getattr(self._val, name)
-        return self
-
-    own_property = own_proper
-
     def keys(self, *args):
         '''
         键值列表断言. 针对字典的键
@@ -241,9 +227,25 @@ class _Should(object):
                 keys.append(i)
 
         for key in keys:
-            self.key(key)
+            self.__key(key)
         return self
 
+    def proper(self, name):
+        self.__property(name, False)
+        # 修改链式调用中需要断言的值
+        self._val = getattr(self._val, name, None)
+        return self
+
+    property = proper
+
+    def own_proper(self, name):
+        self.__property(name, True)
+        # 修改链式调用中需要断言的值
+        self._val = getattr(self._val, name, None)
+        return self
+
+    own_property = own_proper
+
     def properties(self, *args):
         '''
         属性列表断言. 包含类属性以及继承得到的属性
@@ -278,6 +280,15 @@ class _Should(object):
             self.__property(proper, True)
         return self
 
+    def __key(self, name):
+        res = name in self._val
+        if  self._not:
+            res = not res
+        msg_format = '{0} should{1} have key {2}'.format
+        msg = msg_format(self._val, self._flag, name)
+        self._assert(res, msg)
+        return self
+
     def __property(self, name, own=False):
         if own:
             pps = self._val.__dict__.keys()
